/* ISC license. */

#ifndef SKALIBS_STDCRYPTO_H
#define SKALIBS_STDCRYPTO_H

#include <skalibs/sha1.h>
#include <skalibs/sha256.h>
#include <skalibs/sha512.h>

#endif
